@@ -1,3 +1,4 @@
+// clang-format off
 /*
  * KDiff3 - Text Diff And Merge Tool
  *
@@ -14,7 +15,7 @@
 #include <boost/signals2.hpp>
 #include <type_traits>
 
-struct or
+struct or_
 {
     typedef bool result_type;
     template <typename InputIterator> bool operator()(InputIterator first, InputIterator last) const
@@ -35,7 +36,7 @@ struct or
     }
 };
 
-struct and
+struct and_
 {
     typedef bool result_type;
     template <typename InputIterator> bool operator()(InputIterator first, InputIterator last) const
@@ -103,7 +104,10 @@ struct find
 };
 #ifdef BOOST_NO_EXCEPTIONS
 //Because boost doesn't define this
-inline void boost::throw_exception(std::exception const& e) { Q_UNUSED(e); std::terminate();}
+inline void boost::throw_exception([[maybe_unused]] std::exception const& e)
+{
+    std::terminate();
+}
 #endif
 
 #endif // !COMBINERS_H
