@@ -94,14 +94,14 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(ChangeFlags);
 class Diff
 {
   private:
-    LineCount nofEquals = 0;
+    SafeInt<LineType> nofEquals = 0;
 
-    qint64 mDiff1 = 0;
-    qint64 mDiff2 = 0;
+    SafeInt<quint64> mDiff1 = 0;
+    SafeInt<quint64> mDiff2 = 0;
 
   public:
-    Diff() = default;//We use defualt initialization force compiler to generate a default constructor
-    Diff(LineCount eq, const qint64 inDiff1, const qint64 inDiff2)
+    Diff() = default; //We use default initialization force compiler to generate a default constructor
+    Diff(LineType eq, const quint64 inDiff1, const quint64 inDiff2)
     {
         assert(eq >= 0);
         nofEquals = eq;
@@ -111,10 +111,10 @@ class Diff
 
     [[nodiscard]] bool isEmpty() const { return nofEquals == 0 && mDiff1 == 0 && mDiff2 == 0;}
 
-    Q_REQUIRED_RESULT inline qint32 numberOfEquals() const { return nofEquals; };
+    [[nodiscard]] inline qint32 numberOfEquals() const { return nofEquals; };
 
-    Q_REQUIRED_RESULT inline qint64 diff1() const { return mDiff1; };
-    Q_REQUIRED_RESULT inline qint64 diff2() const { return mDiff2; };
+    [[nodiscard]] inline quint64 diff1() const { return mDiff1; };
+    [[nodiscard]] inline quint64 diff2() const { return mDiff2; };
 
     inline void setNumberOfEquals(const qint32 inNumOfEquals) { nofEquals = inNumOfEquals; }
 
@@ -131,6 +131,16 @@ class Diff
     {
         return !(*this == b);
     };
+
+    inline void refine()
+    {
+        if(nofEquals < 4 && (mDiff1 > 0 || mDiff2 > 0))
+        {
+            mDiff1 += nofEquals;
+            mDiff2 += nofEquals;
+            nofEquals = 0;
+        }
+    }
 };
 
 class DiffList: public std::list<Diff>
@@ -138,8 +148,11 @@ class DiffList: public std::list<Diff>
   public:
     using std::list<Diff>::list;
     void calcDiff(const QString& line1, const QString& line2, const qint32 maxSearchRange);
-    void runDiff(const std::shared_ptr<LineDataVector> &p1, const size_t index1, LineRef size1, const std::shared_ptr<LineDataVector> &p2, const size_t index2, LineRef size2, const QSharedPointer<Options>& pOptions);
+    void runDiff(const std::shared_ptr<LineDataVector>& p1, const size_t index1, LineRef size1, const std::shared_ptr<LineDataVector>& p2, const size_t index2, LineRef size2);
+#ifndef NDEBUG
     void verify(const LineRef size1, const LineRef size2);
+#endif
+    void optimize();
 };
 
 class LineData
@@ -154,7 +167,6 @@ class LineData
     bool bSkipable = false;//TODO: Move me
 
   public:
-    explicit LineData() = default; // needed for Qt internal reasons should not be used.
     inline LineData(const QSharedPointer<QString>& buffer, const QtSizeType inOffset, QtSizeType inSize = 0, QtSizeType inFirstNonWhiteChar = 0, bool inIsSkipable = false, const bool inIsPureComment = false)
     {
         mBuffer = buffer;
@@ -164,27 +176,27 @@ class LineData
         bSkipable = inIsSkipable;
         mFirstNonWhiteChar = inFirstNonWhiteChar;
     }
-    Q_REQUIRED_RESULT inline QtSizeType size() const { return mSize; }
-    Q_REQUIRED_RESULT inline qint32 getFirstNonWhiteChar() const { return mFirstNonWhiteChar; }
+    [[nodiscard]] inline QtSizeType size() const { return mSize; }
+    [[nodiscard]] inline QtSizeType getFirstNonWhiteChar() const { return mFirstNonWhiteChar; }
 
     /*
-        QString::fromRawData allows us to create a light weight QString backed by the buffer memmory.
+        QString::fromRawData allows us to create a light weight QString backed by the buffer memory.
     */
-    Q_REQUIRED_RESULT inline const QString getLine() const { return QString::fromRawData(mBuffer->data() + mOffset, mSize); }
-    Q_REQUIRED_RESULT inline const QSharedPointer<QString>& getBuffer() const { return mBuffer; }
+    [[nodiscard]] inline const QString getLine() const { return QString::fromRawData(mBuffer->data() + mOffset, mSize); }
+    [[nodiscard]] inline const QSharedPointer<QString>& getBuffer() const { return mBuffer; }
 
-    Q_REQUIRED_RESULT inline QtSizeType getOffset() const { return mOffset; }
-    Q_REQUIRED_RESULT qint32 width(qint32 tabSize) const; // Calcs width considering tabs.
+    [[nodiscard]] inline QtSizeType getOffset() const { return mOffset; }
+    [[nodiscard]] qint32 width(qint32 tabSize) const; // Calcs width considering tabs.
 
-    Q_REQUIRED_RESULT inline bool whiteLine() const { return mFirstNonWhiteChar == 0; }
+    [[nodiscard]] inline bool whiteLine() const { return mFirstNonWhiteChar == 0; }
 
-    Q_REQUIRED_RESULT inline bool isPureComment() const { return bContainsPureComment; }
+    [[nodiscard]] inline bool isPureComment() const { return bContainsPureComment; }
     inline void setPureComment(const bool bPureComment) { bContainsPureComment = bPureComment; }
 
-    Q_REQUIRED_RESULT inline bool isSkipable() const { return bSkipable; }
+    [[nodiscard]] inline bool isSkipable() const { return bSkipable; }
     inline void setSkipable(const bool inSkipable) { bSkipable = inSkipable; }
 
-    Q_REQUIRED_RESULT static bool equal(const LineData& l1, const LineData& l2);
+    [[nodiscard]] static bool equal(const LineData& l1, const LineData& l2);
 };
 
 class ManualDiffHelpList; // A list of corresponding ranges
@@ -248,9 +260,9 @@ class Diff3Line
     bool bWhiteLineB = false;
     bool bWhiteLineC = false;
 
-    std::shared_ptr<DiffList> pFineAB; // These are NULL only if completely equal or if either source doesn't exist.
-    std::shared_ptr<DiffList> pFineBC;
-    std::shared_ptr<DiffList> pFineCA;
+    std::shared_ptr<const DiffList> pFineAB; // These are NULL only if completely equal or if either source doesn't exist.
+    std::shared_ptr<const DiffList> pFineBC;
+    std::shared_ptr<const DiffList> pFineCA;
 
     qint32 mLinesNeededForDisplay = 1;    // Due to wordwrap
     qint32 mSumLinesNeededForDisplay = 0; // For fast conversion to m_diff3WrapLineVector
@@ -261,7 +273,7 @@ class Diff3Line
     [[nodiscard]] inline bool hasFineDiffBC() const { return pFineBC != nullptr; }
     [[nodiscard]] inline bool hasFineDiffCA() const { return pFineCA != nullptr; }
 
-    [[nodiscard]] inline LineRef getLineIndex(e_SrcSelector src) const
+    [[nodiscard]] inline LineType getLineIndex(e_SrcSelector src) const
     {
         switch(src)
         {
@@ -277,19 +289,19 @@ class Diff3Line
         }
     }
 
-    Q_REQUIRED_RESULT LineRef getLineA() const { return lineA; }
-    Q_REQUIRED_RESULT LineRef getLineB() const { return lineB; }
-    Q_REQUIRED_RESULT LineRef getLineC() const { return lineC; }
+    [[nodiscard]] LineRef getLineA() const { return lineA; }
+    [[nodiscard]] LineRef getLineB() const { return lineB; }
+    [[nodiscard]] LineRef getLineC() const { return lineC; }
 
     inline void setLineA(const LineRef& line) { lineA = line; }
     inline void setLineB(const LineRef& line) { lineB = line; }
     inline void setLineC(const LineRef& line) { lineC = line; }
 
-    Q_REQUIRED_RESULT inline bool isEqualAB() const { return bAEqB; }
-    Q_REQUIRED_RESULT inline bool isEqualAC() const { return bAEqC; }
-    Q_REQUIRED_RESULT inline bool isEqualBC() const { return bBEqC; }
+    [[nodiscard]] inline bool isEqualAB() const { return bAEqB; }
+    [[nodiscard]] inline bool isEqualAC() const { return bAEqC; }
+    [[nodiscard]] inline bool isEqualBC() const { return bBEqC; }
 
-    Q_REQUIRED_RESULT inline bool isWhiteLine(e_SrcSelector src) const
+    [[nodiscard]] inline bool isWhiteLine(e_SrcSelector src) const
     {
         assert(src == e_SrcSelector::A || src == e_SrcSelector::B || src == e_SrcSelector::C);
 
@@ -315,7 +327,7 @@ class Diff3Line
                bWhiteLineA == d3l.bWhiteLineA && bWhiteLineB == d3l.bWhiteLineB && bWhiteLineC == d3l.bWhiteLineC;
     }
 
-    Q_REQUIRED_RESULT const LineData& getLineData(e_SrcSelector src) const
+    [[nodiscard]] const LineData& getLineData(e_SrcSelector src) const
     {
         assert(m_pDiffBufferInfo != nullptr);
         assert(src == e_SrcSelector::A || src == e_SrcSelector::B || src == e_SrcSelector::C);
@@ -324,13 +336,15 @@ class Diff3Line
         if(src == e_SrcSelector::B && lineB.isValid()) return m_pDiffBufferInfo->getLineData(src)->at(lineB);
         return m_pDiffBufferInfo->getLineData(src)->at(lineC);
     }
-    Q_REQUIRED_RESULT const QString getString(const e_SrcSelector src) const
+
+    [[nodiscard]] const QString getString(const e_SrcSelector src) const
     {
         const LineData& pld = getLineData(src);
 
         return pld.getLine();
     }
-    Q_REQUIRED_RESULT LineRef getLineInFile(e_SrcSelector src) const
+
+    [[nodiscard]] LineRef getLineInFile(e_SrcSelector src) const
     {
         if(src == e_SrcSelector::A) return lineA;
         if(src == e_SrcSelector::B) return lineB;
@@ -338,18 +352,18 @@ class Diff3Line
         return LineRef();
     }
 
-    Q_REQUIRED_RESULT inline qint32 sumLinesNeededForDisplay() const { return mSumLinesNeededForDisplay; }
+    [[nodiscard]] inline qint32 sumLinesNeededForDisplay() const { return mSumLinesNeededForDisplay; }
 
-    Q_REQUIRED_RESULT inline qint32 linesNeededForDisplay() const { return mLinesNeededForDisplay; }
+    [[nodiscard]] inline qint32 linesNeededForDisplay() const { return mLinesNeededForDisplay; }
 
     void setLinesNeeded(const qint32 lines) { mLinesNeededForDisplay = lines; }
-    Q_REQUIRED_RESULT bool fineDiff(bool bTextsTotalEqual, const e_SrcSelector selector, const std::shared_ptr<LineDataVector> &v1, const std::shared_ptr<LineDataVector> &v2, const IgnoreFlags eIgnoreFlags);
+    [[nodiscard]] bool fineDiff(bool bTextsTotalEqual, const e_SrcSelector selector, const std::shared_ptr<LineDataVector>& v1, const std::shared_ptr<LineDataVector>& v2, const IgnoreFlags eIgnoreFlags);
     void getLineInfo(const e_SrcSelector winIdx, const bool isTriple, LineRef& lineIdx,
-                     std::shared_ptr<DiffList>& pFineDiff1, std::shared_ptr<DiffList>& pFineDiff2, // return values
+                     std::shared_ptr<const DiffList>& pFineDiff1, std::shared_ptr<const DiffList>& pFineDiff2, // return values
                      ChangeFlags& changed, ChangeFlags& changed2) const;
 
   private:
-    void setFineDiff(const e_SrcSelector selector, std::shared_ptr<DiffList>& pDiffList)
+    void setFineDiff(const e_SrcSelector selector, const std::shared_ptr<DiffList>& pDiffList)
     {
         assert(selector == e_SrcSelector::A || selector == e_SrcSelector::B || selector == e_SrcSelector::C);
         if(selector == e_SrcSelector::A)
@@ -387,9 +401,9 @@ class Diff3LineList: public std::list<Diff3Line>
 
     void calcDiff3LineListTrim(const std::shared_ptr<LineDataVector> &pldA, const std::shared_ptr<LineDataVector> &pldB, const std::shared_ptr<LineDataVector> &pldC, ManualDiffHelpList* pManualDiffHelpList);
 
-    LineCount recalcWordWrap(bool resetDisplayCount)
+    LineType recalcWordWrap(bool resetDisplayCount)
     {
-        LineCount sumOfLines = 0;
+        LineType sumOfLines = 0;
 
         for(Diff3Line& d3l: *this)
         {
@@ -403,15 +417,15 @@ class Diff3LineList: public std::list<Diff3Line>
         return sumOfLines;
     }
 
-    void debugLineCheck(const LineCount size, const e_SrcSelector srcSelector) const;
+    void debugLineCheck(const LineType size, const e_SrcSelector srcSelector) const;
 
     void dump();
 
-    [[nodiscard]] LineCount numberOfLines(bool bWordWrap) const
+    [[nodiscard]] LineType numberOfLines(bool bWordWrap) const
     {
         if(bWordWrap)
         {
-            LineCount lines;
+            LineType lines;
 
             lines = 0;
             Diff3LineList::const_iterator i;
@@ -424,7 +438,7 @@ class Diff3LineList: public std::list<Diff3Line>
         }
         else
         {
-            return SafeInt<LineCount>(size());
+            return SafeInt<LineType>(size());
         }
     }
 };
@@ -440,7 +454,7 @@ struct HistoryRange
 struct Diff3WrapLine
 {
     Diff3Line* pD3L = nullptr;
-    qint32 diff3LineIndex = 0;
+    LineType diff3LineIndex = 0;
     qint32 wrapLineOffset = 0;
     qint32 wrapLineLength = 0;
 };
@@ -539,14 +553,17 @@ class ManualDiffHelpEntry
     {
         return winIdx == e_SrcSelector::A ? lineA1 : (winIdx == e_SrcSelector::B ? lineB1 : lineC1);
     }
+
     LineRef& lastLine(e_SrcSelector winIdx)
     {
         return winIdx == e_SrcSelector::A ? lineA2 : (winIdx == e_SrcSelector::B ? lineB2 : lineC2);
     }
+
     bool isLineInRange(LineRef line, e_SrcSelector winIdx)
     {
         return line.isValid() && line >= firstLine(winIdx) && line <= lastLine(winIdx);
     }
+
     bool operator==(const ManualDiffHelpEntry& r) const
     {
         return lineA1 == r.lineA1 && lineB1 == r.lineB1 && lineC1 == r.lineC1 &&
@@ -583,12 +600,13 @@ class ManualDiffHelpEntry
 class ManualDiffHelpList: public std::list<ManualDiffHelpEntry>
 {
   public:
-    Q_REQUIRED_RESULT bool isValidMove(LineRef line1, LineRef line2, e_SrcSelector winIdx1, e_SrcSelector winIdx2) const;
+    using std::list<ManualDiffHelpEntry>::list;
+
+    [[nodiscard]] bool isValidMove(LineRef line1, LineRef line2, e_SrcSelector winIdx1, e_SrcSelector winIdx2) const;
     void insertEntry(e_SrcSelector winIdx, LineRef firstLine, LineRef lastLine);
 
-    void runDiff(const std::shared_ptr<LineDataVector> &p1, LineRef size1, const std::shared_ptr<LineDataVector> &p2, LineRef size2, DiffList& diffList,
-                 e_SrcSelector winIdx1, e_SrcSelector winIdx2,
-                 const QSharedPointer<Options>& pOptions);
+    void runDiff(const std::shared_ptr<LineDataVector>& p1, LineRef size1, const std::shared_ptr<LineDataVector>& p2, LineRef size2, DiffList& diffList,
+                 e_SrcSelector winIdx1, e_SrcSelector winIdx2);
 };
 
 /** Returns the number of equivalent spaces at position outPos.
@@ -602,7 +620,7 @@ inline qint32 tabber(qint32 outPos, qint32 tabSize)
     be displayed best. If it fits into the currently visible range then
     the returned value is the current firstLine.
 */
-qint32 getBestFirstLine(qint32 line, qint32 nofLines, qint32 firstLine, qint32 visibleLines);
+LineRef getBestFirstLine(LineRef line, LineType nofLines, LineRef firstLine, LineType visibleLines);
 
 enum e_CoordType
 {
