@@ -18,7 +18,7 @@
 class Merger
 {
   public:
-    Merger(const std::shared_ptr<DiffList>& pDiffList1, const std::shared_ptr<DiffList>& pDiffList2);
+    Merger(const std::shared_ptr<const DiffList>& pDiffList1, const std::shared_ptr<const DiffList>& pDiffList2);
 
     /** Go one step. */
     void next();
@@ -38,12 +38,12 @@ class Merger
     {
       private:
         DiffList::const_iterator it;
-        std::shared_ptr<DiffList> pDiffList;
+        std::shared_ptr<const DiffList> pDiffList;
         Diff d;
         qint32 idx;
 
       public:
-        MergeData(const std::shared_ptr<DiffList>& p, qint32 i);
+        MergeData(const std::shared_ptr<const DiffList>& p, qint32 i);
         [[nodiscard]] bool eq() const;
         void update();
         [[nodiscard]] bool isEnd() const;
